bayespy.plot.FunctionPlotter
============================

.. currentmodule:: bayespy.plot

.. autoclass:: FunctionPlotter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~FunctionPlotter.__init__
   
   

   
   
   